@@ -3,19 +3,19 @@ import os
 import shutil
 
 # noinspection PyPackageRequirements
-from os import path
+from typing import Any
 
 import pytest
 from pyspark.sql import SparkSession
 
 # make sure env variables are set correctly
-if 'SPARK_HOME' not in os.environ:
-    os.environ['SPARK_HOME'] = '/usr/local/opt/spark'
+if "SPARK_HOME" not in os.environ:
+    os.environ["SPARK_HOME"] = "/usr/local/opt/spark"
 
 
 def quiet_py4j() -> None:
     """ turn down spark logging for the carriers context """
-    logger = logging.getLogger('py4j')
+    logger = logging.getLogger("py4j")
     logger.setLevel(logging.ERROR)
 
 
@@ -52,7 +52,7 @@ def clean_spark_session(session: SparkSession) -> None:
     session.catalog.clearCache()
 
 
-def clean_close(session) -> None:
+def clean_close(session: SparkSession) -> None:
     """
 
     :param session:
@@ -64,28 +64,25 @@ def clean_close(session) -> None:
 
 
 @pytest.fixture(scope="session")
-def spark_session(request) -> SparkSession:
+def spark_session(request: Any) -> SparkSession:
     # make sure env variables are set correctly
-    if 'SPARK_HOME' not in os.environ:
-        os.environ['SPARK_HOME'] = '/usr/local/opt/spark'
+    if "SPARK_HOME" not in os.environ:
+        os.environ["SPARK_HOME"] = "/usr/local/opt/spark"
 
     clean_spark_dir()
 
-    master: str = "spark://localhost:7077"
-    if not path.exists("/Applications/Docker.app"):
-        master = "local[2]"
-        print(f"++++++ Running on local spark: {master} ++++")
-    else:
-        print(f"++++++ Running on docker spark: {master} ++++")
+    master = "local[2]"
 
-    session = SparkSession.builder.appName("pytest-pyspark-local-testing"). \
-        master(master). \
-        config("spark.ui.showConsoleProgress", "false"). \
-        config("spark.sql.shuffle.partitions", "2"). \
-        config("spark.default.parallelism", "4"). \
-        config("spark.sql.broadcastTimeout", "2400"). \
-        enableHiveSupport(). \
-        getOrCreate()
+    session = (
+        SparkSession.builder.appName("pytest-pyspark-local-testing")
+        .master(master)
+        .config("spark.ui.showConsoleProgress", "false")
+        .config("spark.sql.shuffle.partitions", "2")
+        .config("spark.default.parallelism", "4")
+        .config("spark.sql.broadcastTimeout", "2400")
+        .enableHiveSupport()
+        .getOrCreate()
+    )
 
     request.addfinalizer(lambda: clean_close(session))
     quiet_py4j()
